# APPXF

APPXF covers cross functional concerns like configuration, persisting data,
logging or security to limit the effort writing simple applications.

__What it is:__ I transfer reusable parts into this package with a strong intend of
the content being useful for others.

__What it could be:__ With support from you, it could start closing a gap anyone
needs to cross when writing even a small application to support small
associations or non-profits.

In Construction
===============
The package is currently "in construction". Main concerns:
  * split from private sources to clarify licensing before publication
  * in the middle of a core feature increase to settle further interfaces
Versions 0.0.x will cover this transitional phase. Target is a preliminary
release as 0.1.0 where interfaces may still be unstable.

It is made public already to:
  1) gather experience with the packaging
  2) allow a stepwise transition
